<?php
/*
 * Version 1.0 | 20-Juli-2024 | Projekt: LoRaWAN Wassertemperatur Messstation
 * https://www.aeq-web.com/ttn-lorawan-data-view-php-website/
*/

$json = file_get_contents('data.json');
$data = json_decode($json, true);

$wt_temperature = $data["uplink_message"]["decoded_payload"]["Temperature_Sensor"];
$th_temperature = $data["uplink_message"]["decoded_payload"]["TH_Sensor_Temperature"];
$th_humidity = $data["uplink_message"]["decoded_payload"]["TH_Sensor_Humidity"];
$voltage = round(($data["uplink_message"]["decoded_payload"]["Supply_Voltage"]) / 1000, 2);

$gateway = $data["uplink_message"]["rx_metadata"][0]["gateway_ids"]["gateway_id"];
$rssi = $data["uplink_message"]["rx_metadata"][0]["rssi"];
$sf = $data["uplink_message"]["settings"]["data_rate"]["lora"]["spreading_factor"];

$datestring = preg_replace('/\.\d+Z$/', 'Z', $data["received_at"]);
$date = new DateTime($datestring, new DateTimeZone('UTC'));
$date->setTimezone(new DateTimeZone('Europe/Berlin'));
$datetime = $date->format('d.m.Y H:i:s');
$date_now = new DateTime('now', new DateTimeZone('Europe/Berlin'));
$seconds_counter = $date_now->getTimestamp() - $date->getTimestamp();
?>

<html>
    <head>
        <style>
            #valuetable {
                font-family: Arial, Helvetica, sans-serif;
                border-collapse: collapse;
                width: 400px;
                text-align: center;
            }

            #valuetable td, #ttnvalues th {
                border: 1px solid #ddd;
                padding: 8px;
            }

            #valuetable tr:nth-child(even) {
                background-color: #f2f2f2;
            }

            #valuetable tr:hover {
                background-color: #ddd;
            }

            #valuetable th {
                padding-top: 12px;
                padding-bottom: 12px;
                text-align: center;
                background-color: #6699ff;
                color: white;
            }
        </style>

        <script>
            var sec = <?php echo $seconds_counter; ?>;
            var datetime = "<?php echo $datetime; ?>";
            setInterval(function () {
                sec++;
                if (sec < 120) {
                    document.getElementById("datetimeview").innerHTML = "vor " + sec + " sek.";
                } else if (sec < 900) {
                    document.getElementById("datetimeview").innerHTML = "vor " + Math.round(sec / 60) + " min.";
                } else {
                    document.getElementById("datetimeview").innerHTML = datetime;
                }
            }, 1000);
        </script>
        <meta name="viewport" content="width=device-width, initial-scale=0.9" />
    </head>
    <body>
        <table id="valuetable">
            <tr>
                <th>Wassertemp. Messstation</th>
                <th>Messwerte</th>
            </tr>
            <tr>
                <td>Messung</td>
                <td id="datetimeview"><?php echo $datetime; ?></td>
            </tr>
            <tr>
                <td><b>Wassertemperatur</b></td>
                <td><b><?php echo $wt_temperature; ?> &deg;C</b></td>
            </tr>
            <tr>
                <td>Geh&auml;use</td>
                <td><?php echo 'T: ' . $th_temperature . ' &deg;C F: ' . $th_humidity . ' %'; ?></td>
            </tr>
            <tr>
                <td>Batterie</td>
                <td><?php echo $voltage; ?> V</td>
            </tr>
            <tr>
                <td>Gateway</td>
                <td><?php echo $gateway; ?></td>
            </tr>
            <tr>
                <td>Signalst&auml;rke</td>
                <td>RSSI: <?php echo $rssi; ?> dbm / SF<?php echo $sf; ?></td>
            </tr>
        </table>
    </body>
</html>
